/*
 * SPDX-License-Identifier: GPL-2.0-with-classpath-exception
 *
 * common_ini_test.c
 *
 * Copyright (c) 2023 Cisco Systems, Inc. and/or its affiliates
 * All rights reserved.
 */

#include <stdio.h>
#include <string.h>
#include "src/unity.h"
#include "util.h"

const char *SECTION = "\0";
const char *EMPTY_STR = "";
const char *NULL_STR = "\0";
